import requests
import os
import xbmcvfs
import xbmcgui
import shutil

# URL dei file remoti
DEFAULT_PY_URL = "https://repomon.atwebpages.com/plugin.video.monflix/default.py"
MPD_PLAYBACK_PY_URL = "https://repomon.atwebpages.com/plugin.video.monflix/mpd_playback.py"
HLS_PLAYBACK_PY_URL = "https://repomon.atwebpages.com/plugin.video.monflix/hls_playback.py"
ADDON_XML_URL = "https://repomon.atwebpages.com/plugin.video.monflix/addon.xml"
VERSION_FILE_URL = "https://repomon.atwebpages.com/plugin.video.monflix/version.txt"

# Percorsi locali dei file
ADDON_PATH = xbmcvfs.translatePath('special://home/addons/plugin.video.monflix/')
DEFAULT_PY_LOCAL_PATH = os.path.join(ADDON_PATH, 'default.py')
MPD_PLAYBACK_LOCAL_PATH = os.path.join(ADDON_PATH, 'mpd_playback.py')
HLS_PLAYBACK_LOCAL_PATH = os.path.join(ADDON_PATH, 'hls_playback.py')
ADDON_XML_LOCAL_PATH = os.path.join(ADDON_PATH, 'addon.xml')
VERSION_FILE_LOCAL_PATH = os.path.join(ADDON_PATH, 'version.txt')

def check_for_updates():
    try:
        # Verifica la versione corrente
        with open(VERSION_FILE_LOCAL_PATH, 'r') as local_version_file:
            local_version = local_version_file.read().strip()
        
        # Ottiene la versione remota
        response = requests.get(VERSION_FILE_URL)
        remote_version = response.text.strip()

        if local_version != remote_version:
            xbmcgui.Dialog().notification('Aggiornamento', 'Trovato un nuovo aggiornamento. Avvio aggiornamento...', xbmcgui.NOTIFICATION_INFO, 3000)
            update_files()
        else:
            xbmcgui.Dialog().notification('Aggiornamento', 'Non ci sono aggiornamenti disponibili.', xbmcgui.NOTIFICATION_INFO, 3000)

    except Exception as e:
        xbmcgui.Dialog().notification('Errore', f"Errore durante il controllo degli aggiornamenti: {str(e)}", xbmcgui.NOTIFICATION_ERROR, 5000)

def update_files():
    try:
        # Scarica e sovrascrivi default.py
        download_file(DEFAULT_PY_URL, DEFAULT_PY_LOCAL_PATH)

        # Scarica e sovrascrivi mpd_playback.py
        download_file(MPD_PLAYBACK_PY_URL, MPD_PLAYBACK_LOCAL_PATH)

        # Scarica e sovrascrivi hls_playback.py
        download_file(HLS_PLAYBACK_PY_URL, HLS_PLAYBACK_LOCAL_PATH)
        
        # Scarica e sovrascrivi addon.xml
        download_file(ADDON_XML_URL, ADDON_XML_LOCAL_PATH)
        
        # Aggiorna la versione locale
        download_file(VERSION_FILE_URL, VERSION_FILE_LOCAL_PATH)

        xbmcgui.Dialog().notification('Aggiornamento', 'Aggiornamento completato.', xbmcgui.NOTIFICATION_INFO, 5000)
    except Exception as e:
        xbmcgui.Dialog().notification('Errore', f"Errore durante l\'aggiornamento: {str(e)}", xbmcgui.NOTIFICATION_ERROR, 5000)

def download_file(url, local_path):
    response = requests.get(url, stream=True)
    if response.status_code == 200:
        with open(local_path, 'wb') as file:
            shutil.copyfileobj(response.raw, file)
    else:
        raise Exception(f"Impossibile scaricare il file: {url}")
